pub struct KeyEncryptionKey;Expand description
A key-encryption-key (KEK): a key that can be used to encrypt other keys, and shared between users. It MAY be re-used for multiple encrypt operations.
See the key_hierarchy module documentation for its place in the key hierarchy.
Implementations
Sourceimpl KeyEncryptionKey
impl KeyEncryptionKey
Sourcepub fn make<Ids: KeySlotIds>(
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Ids::Symmetric
pub fn make<Ids: KeySlotIds>( ctx: &mut KeyStoreContext<'_, Ids>, ) -> Ids::Symmetric
Generates a fresh key-encryption-key, stores it in the key store context, and returns its key id. Key material never leaves the key store.
Sourcepub(crate) fn is_key_algorithm_valid<Ids: KeySlotIds>(
ctx: &KeyStoreContext<'_, Ids>,
key_id: Ids::Symmetric,
) -> bool
pub(crate) fn is_key_algorithm_valid<Ids: KeySlotIds>( ctx: &KeyStoreContext<'_, Ids>, key_id: Ids::Symmetric, ) -> bool
Returns whether the symmetric key key_id refers to uses an algorithm permitted for a
key-encryption-key. Returns false if the key is missing or uses an unsupported algorithm.